# compile dependency issues, scipy-1.73 and numpy-1.22.x don't work well together
# see https://github.com/scipy/scipy/issues/15414
%bcond_without check

%global srcname scikit-learn

Summary: Machine learning in Python
Name: python-scikit-learn
Version: 1.3.0
Release: 2%{?dist}
License: BSD and MIT
URL: http://scikit-learn.org/
Source0: %{pypi_source}

BuildRequires: gcc gcc-c++
BuildRequires: python3-devel %{py3_dist setuptools}

%description
scikit-learn is a Python module for machine learning built upon numpy, scipy, and matplotlib. 
As a machine learning module, it provides universal tools for data mining and analysis in any 
scientific and engineering field.

%package -n python3-%{srcname}
Summary: %{summary}
BuildRequires: %{py3_dist numpy scipy}
BuildRequires: python3-Cython
%if %{with check}
BuildRequires: python3-pytest
BuildRequires: %{py3_dist joblib}  python3-threadpoolctl
%endif
Provides:       python3-sklearn = %{version}-%{release}

%description -n python3-%{srcname}
scikit-learn is a Python module for machine learning built upon numpy, scipy, and matplotlib. 
As a machine learning module, it provides universal tools for data mining and analysis in any 
scientific and engineering field.

%prep
%autosetup -n %{srcname}-%{version}

%build
%py3_build

%install
%py3_install

%if %{with check}
%check
export PYTHONDONTWRITEBYTECODE=1
export PYTEST_ADDOPTS='-p no:cacheprovider'
pushd %{buildroot}%{python3_sitearch}
  pytest -v -x \
  -k "not test_covariance and not test_shrunk_covariance and \
      not test_ledoit_wolf and not test_oas and not test_mcd and \
      not test_mcd_issue1127 and not test_mcd_support_covariance_is_zero and \
      not test_toy_ard_object and not test_estimators and \
      not test_ard_accuracy_on_easy_problem" \
  --deselect "sklearn/datasets/tests/test_openml.py::test_fetch_openml_verify_checksum[True-liac-arff]" \
  --deselect "sklearn/datasets/tests/test_openml.py::test_fetch_openml_verify_checksum[False-liac-arff]" \
  --deselect "sklearn/datasets/tests/test_openml.py::test_fetch_openml_verify_checksum[True-pandas]" \
  --deselect "sklearn/datasets/tests/test_openml.py::test_fetch_openml_verify_checksum[False-pandas]" \
%ifarch ppc64le
  --deselect "neural_network/tests/test_mlp.py::test_mlp_regressor_dtypes_casting" \
%endif
  sklearn 
popd

%endif

%files -n python3-%{srcname}
%license COPYING sklearn/svm/src/liblinear/COPYRIGHT
%doc examples/
%{python3_sitearch}/sklearn
%{python3_sitearch}/scikit_learn-*.egg-info

%changelog
* Thu Jun 6 2024 Shuo Wang <abushwang@tencent.com> - 1.3.0-2
- disable some tests due to low cpython

* Wed Sep 27 2023 Wang Guodong <gordonwwang@tencent.com> - 1.3.0-1
- Upgrade to version 1.3.0

* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.1.2-5
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.1.2-4
- Rebuilt for OpenCloudOS Stream 23.09

* Mon Sep 04 2023 Wang Guodong <gordonwwang@tencent.com> - 1.1.2-3
- Update BuildRequires: Cython3

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.1.2-2
- Rebuilt for OpenCloudOS Stream 23.05

* Sun Apr 23 2023 Wang Guodong <gordonwwang@tencent.com> - 1.1.2-1
- initial build
